[![pypi](https://img.shields.io/pypi/v/lnschema_bionty?color=%2334D058&label=pypi%20package)](https://pypi.org/project/lnschema_bionty)

# `lnschema_bionty`: Basic biological entities

`lnschema_bionty` is documented & tested within `lamindb`: [github.com/laminlabs/lamindb](https://github.com/laminlabs/lamindb).
